#*****************************************************************************/
#*    IBM CONFIDENTIAL                                                       */
#*    (IBM CONFIDENTIAL-RESTRICTED WHEN COMBINED WITH                        */
#*    THE AGGREGATED OCO SOURCE MODULES FOR THIS PROGRAM)                    */
#*    OCO SOURCE MATERIALS                                                   */
#*                                                                           */
#* Module:          ntadx.mak                                                */
#*                                                                           */
#* Component:       User Exit functions                                      */
#*                                                                           */
#* Description:     Make file                                                */
#*                                                                           */
#* Author:          Paul Theobald                                            */
#*                                                                           */
#* Date:            28 September 1995                                        */
#*                                                                           */
#*****************************************************************************/
#* Overview:                                                                 */
#*   This make file builds the two user exit routine libraries               */
#*                                                                           */
#*   To build CX                                                             */
#*     nmake /f ntadx.mak cx                                                 */
#*   To build SS                                                             */
#*     nmake /f ntadx.mak ss                                                 */
#*   To build SX                                                             */
#*     nmake /f ntadx.mak sx                                                 */
#*   To build all                                                            */
#*     nmake /f ntadx.mak                                                    */
#*                                                                           */
#*****************************************************************************/

#*****************************************************************************/
#* Pick up environment                                                       */
#*****************************************************************************/
!include $(NTBUILD_TOP)\diva\ntenv.mak

CFLAGS    = $(BASICFLAGS)
LFLAGS    = $(LINKFLAGS)
INCLUDE   = -I$(SDKPATH)\INCLUDE -I$(SRC) -I$(SRCUI) -I$(SRCNG)

#*****************************************************************************/
#* Variables specific to this build                                          */
#* - MAKE:      Make file name                                               */
#* - EXEC:      EXE/DLL name                                                 */
#* - LINK:      Link response file name                                      */
#* - IMPORT:    Import file name                                             */
#* - DEF:       DEF file name                                                */
#* - OBJS:      Objects                                                      */
#* - DEPENDS:   Dependencies                                                 */
#*****************************************************************************/
MAKE      = $(SRC)\ntadx.mak
LIBCX     = fndcx.dll
LIBSX     = fndsx.dll
LIBSS     = fndss.dll
LINKCX    = fndcx.lnk
LINKSX    = fndsx.lnk
LINKSS    = fndss.lnk
IMPORTCX  = fndcx.lib
IMPORTSX  = fndsx.lib
IMPORTSS  = fndss.lib
DEFCX     = fndcx.def
DEFSX     = fndsx.def
DEFSS     = fndss.def
!IF  "$(COMP_TYPE)" == "WIN32S"
OBJSCX    = fndcx.obj fndcxcm.obj fndcxmo.obj fnd32exe.obj
!ELSE
OBJSCX    = fndcx.obj fndcxcm.obj fndcxmo.obj fnd32exe.obj
!ENDIF
OBJSSX    = fndsx.obj
OBJSSS    = fndssext.obj

#*****************************************************************************/
#* All commands:                                                             */
#* - all:     objects built by default                                       */
#* - import:  import libraries                                               */
#* - full:    force full rebuild                                             */
#*****************************************************************************/
all:
          cd $(OBJBASE)
          nmake /f $(MAKE) imp cx sx ss

full:
          cd $(OBJBASE)
          for %i in ($(OBJSCX) $(OBJSSX) $(OBJSSS)) do del %i
          nmake /f $(MAKE)

import:
          cd $(OBJBASE)
          nmake /f $(MAKE) imp

cx:             $(IMPORTCX) $(LIBCX)

sx:             $(IMPORTSX) $(LIBSX)

ss:             $(IMPORTSS) $(LIBSS)

imp:            $(IMPORTCX) $(IMPORTSX) $(IMPORTSS)

#*****************************************************************************/
#* Build the DACA User Exit library                                          */
#*****************************************************************************/
$(LIBCX): $(OBJSCX) $(LINKCX)
         $(LINKCMD) $(LFLAGS) @$(LINKCX)

$(LINKCX): $(MAKE)
  echo /COMMENT:"$(PRODUCT_NAME) DACA user exit"                         >$@
  echo /COMMENT:$(COPYRIGHT)                                            >>$@
  for %i in ($(OBJSCX)) do echo %i                                      >>$@
  echo /OUT:$(LIBCX)                                                    >>$@
  echo /MAP:$(@B).map                                                   >>$@
!IF  "$(COMP_TYPE)" == "WIN32S"
  for %i in ($(SYSLIBS)) do echo %i.lib             >>$@
!ENDIF
  echo /DLL                                                             >>$@
  echo $(@B).exp                                                        >>$@

$(IMPORTCX): $(MAKE) $(DEFCX)
  $(LIBCMD) $(LIBFLAGS):$(DEFCX)

$(DEFCX): $(MAKE)
  echo LIBRARY $(@B)                                                     >$@
  echo EXPORTS                                                          >>$@
  echo cx_daca_filename                                                 >>$@
  echo cx_daca_report                                                   >>$@
  echo cx_daca_request                                                  >>$@
  echo sx_server_request                                                >>$@
  echo sx_server_report                                                 >>$@
  echo cx_mount_fs                                                      >>$@
  echo cx_unmount_fs                                                    >>$@
  echo cx_vercm                                                         >>$@
  echo cx_check_crcs                                                    >>$@
  echo cx_check_secure_key                                              >>$@
  echo cx_set_secure_key                                                >>$@
  echo cx_check_crcs                                                    >>$@
  echo cx_check_secure_key                                              >>$@
  echo cx_set_secure_key                                                >>$@

fndcx.obj:      $(SRC)\fndcx.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRC)\fndcx.c

fndcxcm.obj:    $(SRC)\fndcxcm.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRC)\fndcxcm.c

fndcxmo.obj:    $(SRC)\fndcxmo.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRC)\fndcxmo.c

fnd32exe.obj:    $(SRC)\fnd32exe.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRC)\fnd32exe.c

#*****************************************************************************/
#* Build the Server User Exit library                                        */
#*****************************************************************************/
$(LIBSX): $(OBJSSX) $(LINKSX)
         $(LINKCMD) $(LFLAGS) @$(LINKSX)

$(LINKSX): $(MAKE)
  echo /COMMENT:"$(PRODUCT_NAME) Server user exit"                       >$@
  echo /COMMENT:$(COPYRIGHT)                                            >>$@
  for %i in ($(OBJSSX)) do echo %i                                      >>$@
  echo /OUT:$(LIBSX)                                                    >>$@
  echo /MAP:$(@B).map                                                   >>$@
  echo /DLL                                                             >>$@
  echo $(@B).exp                                                        >>$@

$(IMPORTSX): $(MAKE) $(DEFSX)
  $(LIBCMD) $(LIBFLAGS):$(DEFSX)

$(DEFSX): $(MAKE)
  echo LIBRARY $(@B)                                                     >$@
  echo EXPORTS                                                          >>$@
  echo sx_export_dir                                                    >>$@
  echo sx_unexport_dir                                                  >>$@
  echo sx_usrexit_trgcfg                                                >>$@
  echo sx_usrexit_usrcfg                                                >>$@

fndsx.obj:      $(SRC)\fndsx.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRC)\fndsx.c

#*****************************************************************************/
#* Build the SS User Exit library                                            */
#*****************************************************************************/
$(LIBSS): $(OBJSSS) $(LINKSS)
         $(LINKCMD) $(LFLAGS) @$(LINKSS)

$(LINKSS): $(MAKE)
  echo /COMMENT:"$(PRODUCT_NAME) SS user exit"                           >$@
  echo /COMMENT:$(COPYRIGHT)                                            >>$@
  for %i in ($(OBJSSS)) do echo %i                                      >>$@
  echo /OUT:$(LIBSS)                                                    >>$@
  echo /MAP:$(@B).map                                                   >>$@
  echo /DLL                                                             >>$@
  echo $(@B).exp                                                        >>$@

$(IMPORTSS): $(MAKE) $(DEFSS)
  $(LIBCMD) $(LIBFLAGS):$(DEFSS)

$(DEFSS): $(MAKE)
  echo LIBRARY $(@B)                                                     >$@
  echo EXPORTS                                                          >>$@
  echo ss_user_loc_name                                                 >>$@

fndssext.obj:   $(SRCNG)\fndssext.c
        $(COMPCMD) $(CFLAGS) $(O)$@ $(INCLUDE) $(SRCNG)\fndssext.c
